@@ -9,8 +9,8 @@ __PACKAGE__->data( do{ local $/; <DATA> } );
 
 sub tag {
 	my($self, $doc) = @_;
-	my($name, $path) = fileparse $doc->_get_output_path, qw/\.html/;
-	my $relpath = File::Spec->abs2rel($self->_get_output_path, $path);
+	my($name, $path) = fileparse $doc->get_output_path, qw/\.html/;
+	my $relpath = File::Spec->abs2rel($self->get_output_path, $path);
 	return sprintf qq|<link rel="stylesheet" type="text/css" href="%s" />|, $relpath;
 }
 
